==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationSpecFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PeerAuthenticationSpecFluentImpl<A extends PeerAuthenticationSpecFluent<A>> extends BaseFluent<A> implements PeerAuthenticationSpecFluent<A>{
  public PeerAuthenticationSpecFluentImpl() {
  }
  public PeerAuthenticationSpecFluentImpl(PeerAuthenticationSpec instance) {
    this.withMtls(instance.getMtls()); 
    this.withPortLevelMtls(instance.getPortLevelMtls()); 
    this.withSelector(instance.getSelector()); 
  }
  private PeerAuthenticationMutualTLSBuilder mtls;
  private Map<Long,PeerAuthenticationMutualTLS> portLevelMtls;
  private WorkloadSelectorBuilder selector;
  
  /**
   * This method has been deprecated, please use method buildMtls instead.
   * @return The buildable object.
   */
  @Deprecated
  public PeerAuthenticationMutualTLS getMtls() {
    return this.mtls!=null ?this.mtls.build():null;
  }
  public PeerAuthenticationMutualTLS buildMtls() {
    return this.mtls!=null ?this.mtls.build():null;
  }
  public A withMtls(PeerAuthenticationMutualTLS mtls) {
    _visitables.get("mtls").remove(this.mtls);
    if (mtls!=null){ this.mtls= new PeerAuthenticationMutualTLSBuilder(mtls); _visitables.get("mtls").add(this.mtls);} else { this.mtls = null; _visitables.get("mtls").remove(this.mtls); } return (A) this;
  }
  public Boolean hasMtls() {
    return this.mtls != null;
  }
  public PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtls() {
    return new PeerAuthenticationSpecFluentImpl.MtlsNestedImpl();
  }
  public PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtlsLike(PeerAuthenticationMutualTLS item) {
    return new PeerAuthenticationSpecFluentImpl.MtlsNestedImpl(item);
  }
  public PeerAuthenticationSpecFluent.MtlsNested<A> editMtls() {
    return withNewMtlsLike(getMtls());
  }
  public PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtls() {
    return withNewMtlsLike(getMtls() != null ? getMtls(): new PeerAuthenticationMutualTLSBuilder().build());
  }
  public PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtlsLike(PeerAuthenticationMutualTLS item) {
    return withNewMtlsLike(getMtls() != null ? getMtls(): item);
  }
  public A addToPortLevelMtls(Long key,PeerAuthenticationMutualTLS value) {
    if(this.portLevelMtls == null && key != null && value != null) { this.portLevelMtls = new LinkedHashMap(); }
    if(key != null && value != null) {this.portLevelMtls.put(key, value);} return (A)this;
  }
  public A addToPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null && map != null) { this.portLevelMtls = new LinkedHashMap(); }
    if(map != null) { this.portLevelMtls.putAll(map);} return (A)this;
  }
  public A removeFromPortLevelMtls(Long key) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(key != null && this.portLevelMtls != null) {this.portLevelMtls.remove(key);} return (A)this;
  }
  public A removeFromPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.portLevelMtls != null){this.portLevelMtls.remove(key);}}} return (A)this;
  }
  public Map<Long,PeerAuthenticationMutualTLS> getPortLevelMtls() {
    return this.portLevelMtls;
  }
  public <K,V>A withPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> portLevelMtls) {
    if (portLevelMtls == null) { this.portLevelMtls =  null;} else {this.portLevelMtls = new LinkedHashMap(portLevelMtls);} return (A) this;
  }
  public Boolean hasPortLevelMtls() {
    return this.portLevelMtls != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public WorkloadSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(WorkloadSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new WorkloadSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector() {
    return new PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl();
  }
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item) {
    return new PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl(item);
  }
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector() {
    return withNewSelectorLike(getSelector());
  }
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new WorkloadSelectorBuilder().build());
  }
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PeerAuthenticationSpecFluentImpl that = (PeerAuthenticationSpecFluentImpl) o;
    if (mtls != null ? !mtls.equals(that.mtls) :that.mtls != null) return false;
    if (portLevelMtls != null ? !portLevelMtls.equals(that.portLevelMtls) :that.portLevelMtls != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mtls,  portLevelMtls,  selector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mtls != null) { sb.append("mtls:"); sb.append(mtls + ","); }
    if (portLevelMtls != null && !portLevelMtls.isEmpty()) { sb.append("portLevelMtls:"); sb.append(portLevelMtls + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector); }
    sb.append("}");
    return sb.toString();
  }
  class MtlsNestedImpl<N> extends PeerAuthenticationMutualTLSFluentImpl<PeerAuthenticationSpecFluent.MtlsNested<N>> implements PeerAuthenticationSpecFluent.MtlsNested<N>,Nested<N>{
    MtlsNestedImpl(PeerAuthenticationMutualTLS item) {
      this.builder = new PeerAuthenticationMutualTLSBuilder(this, item);
    }
    MtlsNestedImpl() {
      this.builder = new PeerAuthenticationMutualTLSBuilder(this);
    }
    PeerAuthenticationMutualTLSBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withMtls(builder.build());
    }
    public N endMtls() {
      return and();
    }
    
  }
  class TypeSelectorNestedImpl<N> extends WorkloadSelectorFluentImpl<PeerAuthenticationSpecFluent.TypeSelectorNested<N>> implements PeerAuthenticationSpecFluent.TypeSelectorNested<N>,Nested<N>{
    TypeSelectorNestedImpl(WorkloadSelector item) {
      this.builder = new WorkloadSelectorBuilder(this, item);
    }
    TypeSelectorNestedImpl() {
      this.builder = new WorkloadSelectorBuilder(this);
    }
    WorkloadSelectorBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endTypeSelector() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationSpecFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PeerAuthenticationSpecFluentImpl<A extends PeerAuthenticationSpecFluent<A>> extends BaseFluent<A> implements PeerAuthenticationSpecFluent<A>{
  public PeerAuthenticationSpecFluentImpl() {
  }
  public PeerAuthenticationSpecFluentImpl(PeerAuthenticationSpec instance) {
    if (instance != null) {
      this.withMtls(instance.getMtls());
      this.withPortLevelMtls(instance.getPortLevelMtls());
      this.withSelector(instance.getSelector());
    }
  }
  private PeerAuthenticationMutualTLSBuilder mtls;
  private Map<Long,PeerAuthenticationMutualTLS> portLevelMtls;
  private WorkloadSelectorBuilder selector;
  
  /**
   * This method has been deprecated, please use method buildMtls instead.
   * @return The buildable object.
   */
  @Deprecated
  public PeerAuthenticationMutualTLS getMtls() {
    return this.mtls!=null ?this.mtls.build():null;
  }
  public PeerAuthenticationMutualTLS buildMtls() {
    return this.mtls!=null ?this.mtls.build():null;
  }
  public A withMtls(PeerAuthenticationMutualTLS mtls) {
    _visitables.get("mtls").remove(this.mtls);
    if (mtls!=null){ this.mtls= new PeerAuthenticationMutualTLSBuilder(mtls); _visitables.get("mtls").add(this.mtls);} else { this.mtls = null; _visitables.get("mtls").remove(this.mtls); } return (A) this;
  }
  public Boolean hasMtls() {
    return this.mtls != null;
  }
  public PeerAuthenticationSpecFluentImpl.MtlsNested<A> withNewMtls() {
    return new PeerAuthenticationSpecFluentImpl.MtlsNestedImpl();
  }
  public PeerAuthenticationSpecFluentImpl.MtlsNested<A> withNewMtlsLike(PeerAuthenticationMutualTLS item) {
    return new PeerAuthenticationSpecFluentImpl.MtlsNestedImpl(item);
  }
  public PeerAuthenticationSpecFluentImpl.MtlsNested<A> editMtls() {
    return withNewMtlsLike(getMtls());
  }
  public PeerAuthenticationSpecFluentImpl.MtlsNested<A> editOrNewMtls() {
    return withNewMtlsLike(getMtls() != null ? getMtls(): new PeerAuthenticationMutualTLSBuilder().build());
  }
  public PeerAuthenticationSpecFluentImpl.MtlsNested<A> editOrNewMtlsLike(PeerAuthenticationMutualTLS item) {
    return withNewMtlsLike(getMtls() != null ? getMtls(): item);
  }
  public A addToPortLevelMtls(Long key,PeerAuthenticationMutualTLS value) {
    if(this.portLevelMtls == null && key != null && value != null) { this.portLevelMtls = new LinkedHashMap(); }
    if(key != null && value != null) {this.portLevelMtls.put(key, value);} return (A)this;
  }
  public A addToPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null && map != null) { this.portLevelMtls = new LinkedHashMap(); }
    if(map != null) { this.portLevelMtls.putAll(map);} return (A)this;
  }
  public A removeFromPortLevelMtls(Long key) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(key != null && this.portLevelMtls != null) {this.portLevelMtls.remove(key);} return (A)this;
  }
  public A removeFromPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.portLevelMtls != null){this.portLevelMtls.remove(key);}}} return (A)this;
  }
  public Map<Long,PeerAuthenticationMutualTLS> getPortLevelMtls() {
    return this.portLevelMtls;
  }
  public <K,V>A withPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> portLevelMtls) {
    if (portLevelMtls == null) { this.portLevelMtls =  null;} else {this.portLevelMtls = new LinkedHashMap(portLevelMtls);} return (A) this;
  }
  public Boolean hasPortLevelMtls() {
    return this.portLevelMtls != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public WorkloadSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(WorkloadSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new WorkloadSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public PeerAuthenticationSpecFluentImpl.TypeSelectorNested<A> withNewTypeSelector() {
    return new PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl();
  }
  public PeerAuthenticationSpecFluentImpl.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item) {
    return new PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl(item);
  }
  public PeerAuthenticationSpecFluentImpl.TypeSelectorNested<A> editTypeSelector() {
    return withNewSelectorLike(getSelector());
  }
  public PeerAuthenticationSpecFluentImpl.TypeSelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new WorkloadSelectorBuilder().build());
  }
  public PeerAuthenticationSpecFluentImpl.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PeerAuthenticationSpecFluentImpl that = (PeerAuthenticationSpecFluentImpl) o;
    if (!java.util.Objects.equals(mtls, that.mtls)) return false;

    if (!java.util.Objects.equals(portLevelMtls, that.portLevelMtls)) return false;

    if (!java.util.Objects.equals(selector, that.selector)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mtls,  portLevelMtls,  selector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mtls != null) { sb.append("mtls:"); sb.append(mtls + ","); }
    if (portLevelMtls != null && !portLevelMtls.isEmpty()) { sb.append("portLevelMtls:"); sb.append(portLevelMtls + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector); }
    sb.append("}");
    return sb.toString();
  }
  class MtlsNestedImpl<N> extends PeerAuthenticationMutualTLSFluentImpl<PeerAuthenticationSpecFluentImpl.MtlsNested<N>> implements PeerAuthenticationSpecFluentImpl.MtlsNested<N>,Nested<N>{
    MtlsNestedImpl(PeerAuthenticationMutualTLS item) {
      this.builder = new PeerAuthenticationMutualTLSBuilder(this, item);
    }
    MtlsNestedImpl() {
      this.builder = new PeerAuthenticationMutualTLSBuilder(this);
    }
    PeerAuthenticationMutualTLSBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withMtls(builder.build());
    }
    public N endMtls() {
      return and();
    }
    
  }
  class TypeSelectorNestedImpl<N> extends WorkloadSelectorFluentImpl<PeerAuthenticationSpecFluentImpl.TypeSelectorNested<N>> implements PeerAuthenticationSpecFluentImpl.TypeSelectorNested<N>,Nested<N>{
    TypeSelectorNestedImpl(WorkloadSelector item) {
      this.builder = new WorkloadSelectorBuilder(this, item);
    }
    TypeSelectorNestedImpl() {
      this.builder = new WorkloadSelectorBuilder(this);
    }
    WorkloadSelectorBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endTypeSelector() {
      return and();
    }
    
  }
  
}
